@@ -4,7 +4,6 @@ from base64 import b64decode
 from typing import List, Type
 
 import click
-
 from memfault_cli.authenticator import Authenticator
 from memfault_cli.chunk import MemfaultChunk
 from memfault_cli.context import MemfaultCliClickContext
@@ -57,7 +56,7 @@ def _do_upload_or_raise(
 
     uploader = uploader_cls(ctx=ctx, file_path=path, authenticator=authenticator)
     if not uploader.can_upload_file():
-        raise click.exceptions.UsageError(f"Upload failed!")
+        raise click.exceptions.UsageError("Upload failed!")
     uploader.upload()
 
 
